@@ -10,7 +10,7 @@ use LWP::Protocol::https;
 use Date::Parse 'str2time';
 use WWW::Shorten qw( TinyURL makeashorterlink );
 
-our $VERSION = '1.02'; # VERSION
+our $VERSION = '1.03'; # VERSION
 
 sub init {
     my ($bot) = @_;
@@ -114,8 +114,10 @@ sub init {
 
                 my $printed = 0;
                 for my $item ( @{ $rss->{items} } ) {
-                    my $time = str2time( $item->{pubDate} );
-                    next if ( $time < $since );
+                    my $time = str2time(
+                        ( $item->{dc} and $item->{dc}{date} ) ? $item->{dc}{date} : $item->{pubDate}
+                    );
+                    next if ( not $time or $time < $since );
 
                     my $key = join( '|',
                         $url->{url},
@@ -163,7 +165,7 @@ Bot::IRC::X::Feeds - Bot::IRC plugin to watch and notify on changes in RSS feeds
 
 =head1 VERSION
 
-version 1.02
+version 1.03
 
 =for markdown [![Build Status](https://travis-ci.org/gryphonshafer/Bot-IRC-X-Feeds.svg)](https://travis-ci.org/gryphonshafer/Bot-IRC-X-Feeds)
 [![Coverage Status](https://coveralls.io/repos/gryphonshafer/Bot-IRC-X-Feeds/badge.png)](https://coveralls.io/r/gryphonshafer/Bot-IRC-X-Feeds)
